@@ -230,7 +230,7 @@ test_that("assert breaks appropriately", {
   expect_error(assert(mtcars, in_set(0,1), vs, tree),
                "object 'tree' not found")
   expect_error(assert(mtcars, in_set(0,1), vs, "tree"),
-               "All select\\(\\) inputs must resolve to integer column positions|\"tree\": must resolve to integer column positions, not string")
+               "All select\\(\\) inputs must resolve to integer column positions|\"tree\": must resolve to integer column positions, not string|Strings must match column names. Unkown columns: tree|Strings must match column names. Unknown columns: tree")
   expect_error(assert("tree"),
                "no applicable method for 'select.?' applied to an object of class \"character\"")
 })
@@ -332,7 +332,7 @@ test_that("assert_rows breaks appropriately", {
   expect_error(assert_rows(mtcars, rowSums, in_set(0,1,2), vs, am, tree),
                "object 'tree' not found")
   expect_error(assert_rows(mtcars, rowSums, in_set(0,1,2), vs, am, "tree"),
-               "All select\\(\\) inputs must resolve to integer column positions|\"tree\": must resolve to integer column positions, not string")
+               "All select\\(\\) inputs must resolve to integer column positions|\"tree\": must resolve to integer column positions, not string|Strings must match column names. Unkown columns: tree|Strings must match column names. Unknown columns: tree")
   expect_error(assert_rows("tree"),
                "no applicable method for 'select.?' applied to an object of class \"character\"")
 })
@@ -417,8 +417,9 @@ test_that("insist raises *custom error* if verification fails (using se)", {
 test_that("insist breaks appropriately", {
   expect_error(insist(within_n_sds(5), mtcars$vs),
                "no applicable method for 'select.?' applied to an object of class \"function\"")
-  expect_error(insist(mtcars, within_n_sds(5), "vs"),
-               "All select\\(\\) inputs must resolve to integer column positions|\"vs\": must resolve to integer column positions, not string")
+  # doesn't cause error since dplyr 6
+  #expect_error(insist(mtcars, within_n_sds(5), "vs"),
+  #             "All select\\(\\) inputs must resolve to integer column positions|\"vs\": must resolve to integer column positions, not string")
   expect_error(insist(mtcars, within_n_sds(5), tree),
                "object 'tree' not found")
   expect_error(insist("tree"),
